==> haskell-cmark-gfm-0.2.0-3-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-cmark-gfm.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cmark-gfm
version: 0.2.0
id: cmark-gfm-0.2.0-3GkVhr3Njf21ypVU48y62J
key: cmark-gfm-0.2.0-3GkVhr3Njf21ypVU48y62J
license: BSD-3-Clause
copyright: (C) 2015--17 John MacFarlane, (C) 2017--19 Ashe Connor
maintainer: kivikakk@github.com
author: Ashe Connor
homepage: https://github.com/kivikakk/cmark-gfm-hs
synopsis: Fast, accurate GitHub Flavored Markdown parser and renderer
description:
    This package provides Haskell bindings for
    <https://github.com/github/cmark-gfm libcmark-gfm>, the reference
    parser for <https://github.github.com/gfm/ GitHub Flavored Markdown>, a fully
    specified variant of Markdown. It includes sources for
    libcmark-gfm (0.29.0.gfm.0) and does not require prior installation of the
    C library.
category: Text
abi: ecf0f3751d90256cde8beaf97b961a51
exposed: True
exposed-modules:
    CMarkGFM
import-dirs: /usr/lib/ghc-8.6.5/site-local/cmark-gfm-0.2.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/cmark-gfm-0.2.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/cmark-gfm-0.2.0
hs-libraries: HScmark-gfm-0.2.0-3GkVhr3Njf21ypVU48y62J
extra-libraries:
    cmark-gfm cmark-gfm-extensions
depends:
    base-4.12.0.0 bytestring-0.10.8.2 text-1.2.3.1
haddock-interfaces: /usr/share/doc/haskell-cmark-gfm/html/cmark-gfm.haddock
haddock-html: /usr/share/doc/haskell-cmark-gfm/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cmark-gfm-0.2.0-4-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-cmark-gfm.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cmark-gfm
version: 0.2.0
id: cmark-gfm-0.2.0-Cu8NSFPhA0NKa7fM8zG2uV
key: cmark-gfm-0.2.0-Cu8NSFPhA0NKa7fM8zG2uV
license: BSD-3-Clause
copyright: (C) 2015--17 John MacFarlane, (C) 2017--19 Ashe Connor
maintainer: kivikakk@github.com
author: Ashe Connor
homepage: https://github.com/kivikakk/cmark-gfm-hs
synopsis: Fast, accurate GitHub Flavored Markdown parser and renderer
description:
    This package provides Haskell bindings for
    <https://github.com/github/cmark-gfm libcmark-gfm>, the reference
    parser for <https://github.github.com/gfm/ GitHub Flavored Markdown>, a fully
    specified variant of Markdown. It includes sources for
    libcmark-gfm (0.29.0.gfm.0) and does not require prior installation of the
    C library.
category: Text
abi: e35ff9f27ef7144e9fb5e08fcb5dd359
exposed: True
exposed-modules:
    CMarkGFM
import-dirs: /usr/lib/ghc-8.6.5/site-local/cmark-gfm-0.2.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/cmark-gfm-0.2.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/cmark-gfm-0.2.0
hs-libraries: HScmark-gfm-0.2.0-Cu8NSFPhA0NKa7fM8zG2uV
extra-libraries:
    cmark-gfm cmark-gfm-extensions
depends:
    base-4.12.0.0 bytestring-0.10.8.2 text-1.2.3.1
haddock-interfaces: /usr/share/doc/haskell-cmark-gfm/html/cmark-gfm.haddock
haddock-html: /usr/share/doc/haskell-cmark-gfm/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
